==> haskell-conduit-1.2.6.6-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit
version: 1.2.6.6
id: conduit-1.2.6.6-DP6wmtnPfNiE72BJILsUMh
key: conduit-1.2.6.6-DP6wmtnPfNiE72BJILsUMh
license: MIT
maintainer: michael@snoyman.com
homepage: http://github.com/snoyberg/conduit
synopsis: Streaming data processing library.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.
    .
    @conduit@ is a solution to the streaming data problem, allowing for production, transformation, and consumption of streams of data in constant memory. It is an alternative to lazy I\/O which guarantees deterministic resource handling, and fits in the same general solution space as @enumerator@\/@iteratee@ and @pipes@. For a tutorial, please visit <https://www.fpcomplete.com/user/snoyberg/library-documentation/conduit-overview>.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Data.Conduit Data.Conduit.List Data.Conduit.Internal
    Data.Conduit.Lift Data.Conduit.Internal.Fusion
    Data.Conduit.Internal.List.Stream
hidden-modules: Data.Conduit.Internal.Pipe
                Data.Conduit.Internal.Conduit
abi: de496ee30a33d58b47913174e7a8c1aa
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/conduit-1.2.6.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/conduit-1.2.6.6
data-dir: /usr/share/arm-linux-ghc-8.0.1/conduit-1.2.6.6
hs-libraries: HSconduit-1.2.6.6-DP6wmtnPfNiE72BJILsUMh
depends:
    base-4.9.0.0 exceptions-0.8.2.1-BH4VJoBlnhODiEIhn43wEf
    lifted-base-0.2.3.6-1j3h4N3dJlkKcS6HOknNA
    mmorph-1.0.6-3xsw6wg6Vs2JmwrJVsaYA0
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    resourcet-1.1.7.4-5MzcrbA8GQD6CRuZwV7nMM transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html: /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-1.2.6.6-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit
version: 1.2.6.6
id: conduit-1.2.6.6-7dzpMHI9xLI77nZfBo3r35
key: conduit-1.2.6.6-7dzpMHI9xLI77nZfBo3r35
license: MIT
maintainer: michael@snoyman.com
homepage: http://github.com/snoyberg/conduit
synopsis: Streaming data processing library.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.
    .
    @conduit@ is a solution to the streaming data problem, allowing for production, transformation, and consumption of streams of data in constant memory. It is an alternative to lazy I\/O which guarantees deterministic resource handling, and fits in the same general solution space as @enumerator@\/@iteratee@ and @pipes@. For a tutorial, please visit <https://www.fpcomplete.com/user/snoyberg/library-documentation/conduit-overview>.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Data.Conduit Data.Conduit.List Data.Conduit.Internal
    Data.Conduit.Lift Data.Conduit.Internal.Fusion
    Data.Conduit.Internal.List.Stream
hidden-modules: Data.Conduit.Internal.Pipe
                Data.Conduit.Internal.Conduit
abi: 3b3a393d9f696bfebb01a6b286d4b9b7
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/conduit-1.2.6.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/conduit-1.2.6.6
data-dir: /usr/share/arm-linux-ghc-8.0.1/conduit-1.2.6.6
hs-libraries: HSconduit-1.2.6.6-7dzpMHI9xLI77nZfBo3r35
depends:
    base-4.9.0.0 exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    lifted-base-0.2.3.8-49pRtI70Gt75UpVUvp7oxA
    mmorph-1.0.6-3xsw6wg6Vs2JmwrJVsaYA0
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    resourcet-1.1.7.4-7ox2WcpPuWlGMzC4LJQgzI transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html: /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
